/**
 *
 * Magnolia SimpleMedia Module (http://www.openmindlab.com/lab/products/media.html)
 * Copyright (C)2008 - 2010, Openmind S.r.l. http://www.openmindonline.it
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.sourceforge.openutils.mgnlmedia.media.lifecycle;

import info.magnolia.module.ModuleLifecycle;
import info.magnolia.module.ModuleLifecycleContext;
import net.sourceforge.openutils.mgnlmedia.media.configuration.ImageProcessorsManager;
import net.sourceforge.openutils.mgnlmedia.media.configuration.MediaConfigurationManager;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * Media module lifecycle manager
 * @author molaschi
 */
public class MediaModule implements ModuleLifecycle
{

    /**
     *
     */
    public static final String REPO = "media";

    private Logger log = LoggerFactory.getLogger(MediaModule.class);

    private boolean autoactivate;

    private static MediaModule instance;

    private String version;

    /**
     * Constructor
     */
    public MediaModule()
    {
        instance = this;
    }

    /**
     * Get instance
     * @return media module instance
     */
    public static MediaModule getInstance()
    {
        return instance;
    }

    /**
     * {@inheritDoc}
     */
    public void start(ModuleLifecycleContext ctx)
    {
        log.info("Starting module media");
        ctx.registerModuleObservingComponent("mediatypes", MediaConfigurationManager.getInstance());
        ctx.registerModuleObservingComponent("processors", ImageProcessorsManager.getInstance());
        version = ctx.getCurrentModuleDefinition().getVersion().toString();
    }

    /**
     * {@inheritDoc}
     */
    public void stop(ModuleLifecycleContext ctx)
    {
        log.info("Stopping module media");
    }

    /**
     * Returns the autoactivate.
     * @return the autoactivate
     */
    public boolean isAutoactivate()
    {
        return autoactivate;
    }

    /**
     * Sets the autoactivate.
     * @param autoactivate the autoactivate to set
     */
    public void setAutoactivate(boolean autoactivate)
    {
        this.autoactivate = autoactivate;
    }

    /**
     * Returns the version.
     * @return the version
     */
    public String getVersion()
    {
        return version;
    }

}
